Module server

Module server 

MCP server setup, tool definitions, handlers, and transport dispatch.

Defines Server which implements the MCP ServerHandler trait. Tool registration uses [build_tool_router] to conditionally include tools based on the database backend and read-only setting.

Structs

CreateDatabaseRequest
Request to create a database.
GetTableSchemaRequest
Request to get a table’s schema.
ListTablesRequest
Request to list tables in a database.
QueryRequest
Request for read_query and write_query tools.
Server
MCP server backed by a database backend.