pub struct CreateDatabaseRequest {
pub database_name: String,
}Expand description
Request to create a database.
Fields
database_name: StringTrait Implementations
Sourceimpl Debug for CreateDatabaseRequest
impl Debug for CreateDatabaseRequest
Sourceimpl<'de> Deserialize<'de> for CreateDatabaseRequest
impl<'de> Deserialize<'de> for CreateDatabaseRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateDatabaseRequest
impl JsonSchema for CreateDatabaseRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateDatabaseRequest
impl RefUnwindSafe for CreateDatabaseRequest
impl Send for CreateDatabaseRequest
impl Sync for CreateDatabaseRequest
impl Unpin for CreateDatabaseRequest
impl UnsafeUnpin for CreateDatabaseRequest
impl UnwindSafe for CreateDatabaseRequest