pub struct GetTableSchemaRequest {
pub database_name: String,
pub table_name: String,
}Expand description
Request to get a table’s schema.
Fields
database_name: Stringtable_name: StringTrait Implementations
Sourceimpl Debug for GetTableSchemaRequest
impl Debug for GetTableSchemaRequest
Sourceimpl<'de> Deserialize<'de> for GetTableSchemaRequest
impl<'de> Deserialize<'de> for GetTableSchemaRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetTableSchemaRequest
impl JsonSchema for GetTableSchemaRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetTableSchemaRequest
impl RefUnwindSafe for GetTableSchemaRequest
impl Send for GetTableSchemaRequest
impl Sync for GetTableSchemaRequest
impl Unpin for GetTableSchemaRequest
impl UnsafeUnpin for GetTableSchemaRequest
impl UnwindSafe for GetTableSchemaRequest