pub struct QueryRequest {
pub sql_query: String,
pub database_name: String,
}Expand description
Request for read_query and write_query tools.
Fields
sql_query: Stringdatabase_name: StringTrait Implementations
Sourceimpl Debug for QueryRequest
impl Debug for QueryRequest
Sourceimpl<'de> Deserialize<'de> for QueryRequest
impl<'de> Deserialize<'de> for QueryRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryRequest
impl JsonSchema for QueryRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QueryRequest
impl RefUnwindSafe for QueryRequest
impl Send for QueryRequest
impl Sync for QueryRequest
impl Unpin for QueryRequest
impl UnsafeUnpin for QueryRequest
impl UnwindSafe for QueryRequest